import { UploadUserFile } from '@bole-core/components';

export type FourStreamsMaterialFileTableProps = {
  showUploadBtn?: boolean;
  showCheckBtn?: boolean;
  showDownloadBtn?: boolean;
  showDeleteBtn?: boolean;
  downloadBtnText?: string;
  BusinessTypeEnumText?: { [key: number]: string };
};

export type BaseMaterialFileTableItem<T> = {
  fileBusinessType: T;
  fileList: UploadUserFile[];
};

export type FourStreamsMaterialFileTableItem =
  BaseMaterialFileTableItem<FourStreamsMaterialFileBusinessTypeEnum>;

export type ApplyTransferMaterialFileTableItem =
  BaseMaterialFileTableItem<ApplyTransferFileBusinessTypeEnum>;

export type TransferFileEnumInRewardGrandTableItem =
  BaseMaterialFileTableItem<TransferFileEnumInRewardGrand>;

export enum EnterpriseTypeEnum {
  /**
   * 人力资源公司
   */
  HREnterprise = 10,
  /**
   * 甲方企业
   */
  FirstPartyCompany = 20,
  /**
   * 行业配套
   */
  IndustryMating = 30,
  /**
   * 行业机构
   */
  IndustryBody = 40,
}

export const EnterpriseTypeEnumText = {
  [EnterpriseTypeEnum.HREnterprise]: '人力资源公司',
  [EnterpriseTypeEnum.FirstPartyCompany]: '甲方企业',
  [EnterpriseTypeEnum.IndustryMating]: '行业配套',
  [EnterpriseTypeEnum.IndustryBody]: '行业机构',
};

export enum FourStreamsMaterialFileBusinessTypeEnum {
  /** 园区入驻协议 */
  ParkEnterPactUrl = 10,
  /** 企业完税证明（盖章） */
  RatePaymentFileUrl = 20,
  /** 企业缴税明细汇总表（盖章） */
  TaxSubFileUrl = 30,
  /** 企业营收利润表 */
  OperateProfitesUrl = 40,
  /**
   * 入驻关联说明
   * @deprecated 已经不用了
   */
  EnterRelateUrl = 50,
  /** C端个税完税说明 */
  PersonTaxRatePayUrl = 60,
  /** C端个税完税说明 */
  PersonTaxInstructUrl = 70,
}

export const FourStreamsMaterialFileBusinessTypeEnumText = {
  [FourStreamsMaterialFileBusinessTypeEnum.ParkEnterPactUrl]: '园区入驻协议',
  [FourStreamsMaterialFileBusinessTypeEnum.RatePaymentFileUrl]: '企业完税证明(盖章)',
  [FourStreamsMaterialFileBusinessTypeEnum.TaxSubFileUrl]: '企业缴税明细汇总表(盖章)',
  [FourStreamsMaterialFileBusinessTypeEnum.OperateProfitesUrl]: '企业营收利润表',
  [FourStreamsMaterialFileBusinessTypeEnum.EnterRelateUrl]: '入驻关联说明',
  [FourStreamsMaterialFileBusinessTypeEnum.PersonTaxRatePayUrl]: 'C端个税完税说明',
  [FourStreamsMaterialFileBusinessTypeEnum.PersonTaxInstructUrl]: 'C端完税情况说明',
};

export const FourStreamsMaterialFileBusinessTypeEnumKey = {
  [FourStreamsMaterialFileBusinessTypeEnum.ParkEnterPactUrl]: 'parkEnterPactUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.RatePaymentFileUrl]: 'ratePaymentFileUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.TaxSubFileUrl]: 'taxSubFileUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.OperateProfitesUrl]: 'operateProfitesUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.EnterRelateUrl]: 'enterRelateUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.PersonTaxRatePayUrl]: 'personTaxRatePayUrl',
  [FourStreamsMaterialFileBusinessTypeEnum.PersonTaxInstructUrl]: 'personTaxInstructUrl',
} as const;

export enum ApplyTransferFileBusinessTypeEnum {
  /** 拨付凭证*/
  FinanceToFileUrl = 100,
  /** 充值凭证*/
  TransferToFileUrl = 110,
}

export const ApplyTransferFileBusinessTypeEnumText = {
  [ApplyTransferFileBusinessTypeEnum.FinanceToFileUrl]: '拨付凭证',
  [ApplyTransferFileBusinessTypeEnum.TransferToFileUrl]: '充值凭证',
};

export const ApplyTransferFileBusinessTypeEnumKey = {
  [ApplyTransferFileBusinessTypeEnum.FinanceToFileUrl]: 'financeToFileUrl',
  [ApplyTransferFileBusinessTypeEnum.TransferToFileUrl]: 'transferToFileUrl',
} as const;

export enum TransferFileEnumInRewardGrand {
  /** 拨付凭证*/
  FinanceFileUrl = 200,
  /** 充值凭证*/
  SettleFileUrl = 210,
}

export const TransferFileEnumInRewardGrandText = {
  [TransferFileEnumInRewardGrand.FinanceFileUrl]: '拨付凭证',
  [TransferFileEnumInRewardGrand.SettleFileUrl]: '充值凭证',
};

export const TransferFileEnumInRewardGrandKey = {
  [TransferFileEnumInRewardGrand.FinanceFileUrl]: 'financeFileUrl',
  [TransferFileEnumInRewardGrand.SettleFileUrl]: 'settleFileUrl',
} as const;
